@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "structureddataextractor_p.h"
@@ -29,6 +16,11 @@
 
 using namespace KItinerary;
 
+static bool isJsonLdTag(const HtmlElement &elem)
+{
+    return elem.name() == QLatin1String("script") && elem.attribute(QStringLiteral("type")) == QLatin1String("application/ld+json");
+}
+
 static QByteArray fixupJson(const QByteArray &data)
 {
     auto output(data);
@@ -112,7 +104,10 @@ static void parseMicroData(const HtmlElement &elem, QJsonObject &obj, QJsonArray
             }
         } else if (!prop.isEmpty()) {
             obj.insert(prop, valueForItemProperty(child));
-        } else  {
+        // Maybe there is more JSON-LD inside this microdata tree
+        } else if (isJsonLdTag(child)) {
+            parseJson(child.content().toUtf8(), result);
+        } else {
             // skip intermediate nodes without Microdata annotations
             parseMicroData(child, obj, result);
         }
@@ -123,7 +118,7 @@ static void parseMicroData(const HtmlElement &elem, QJsonObject &obj, QJsonArray
 static void extractRecursive(const HtmlElement &elem, QJsonArray &result)
 {
     // JSON-LD
-    if (elem.name() == QLatin1String("script") && elem.attribute(QStringLiteral("type")) == QLatin1String("application/ld+json")) {
+    if (isJsonLdTag(elem)) {
         parseJson(elem.content().toUtf8(), result);
         return;
     }
