@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "airportdbgenerator.h"
@@ -219,18 +208,17 @@ bool AirportDbGenerator::fetchCountries()
     return true;
 }
 
-void AirportDbGenerator::lookupTimezones()
+void AirportDbGenerator::improveCoordinates()
 {
     for (auto it = m_airportMap.begin(); it != m_airportMap.end(); ++it) {
         if (!(*it).coord.isValid()) {
-            qDebug() << "Airport has no geo coordinate:" << (*it).label << (*it).iataCode << (*it).uri;
-        }
-        (*it).tz = m_tzDb.timezoneForLocation((*it).country, (*it).coord);
-        if ((*it).tz.isEmpty()) {
-            qDebug() << "Failed to find timezone for" << (*it).iataCode << (*it).label << (*it).country << (*it).coord.latitude << (*it).coord.longitude << (*it).uri;
-            ++m_timezoneLoopupFails;
             continue;
         }
+        const auto coord = osmDb.lookup((*it).iataCode, (*it).coord.latitude, (*it).coord.longitude);
+        if (coord.isValid()) {
+            (*it).coord.latitude = coord.latF();
+            (*it).coord.longitude = coord.lonF();
+        }
     }
 }
 
@@ -238,7 +226,13 @@ void KItinerary::Generator::AirportDbGenerator::indexNames()
 {
     for (auto it = m_airportMap.begin(); it != m_airportMap.end(); ++it) {
         auto l = StringUtil::normalize(it.value().label + QLatin1Char(' ') + it.value().alias)
-                 .split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")), QString::SkipEmptyParts);
+                 .split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+                  Qt::SkipEmptyParts
+#else
+                  QString::SkipEmptyParts
+#endif
+                );
         std::for_each(l.begin(), l.end(), [](QString &s) {
             s = s.toCaseFolded();
         });
@@ -296,8 +290,8 @@ bool AirportDbGenerator::generate(QIODevice* out)
         return false;
     }
 
-    // step 2 augment the data with timezones
-    lookupTimezones();
+    // step 2 augment the data with optimized OSM airport positions
+    improveCoordinates();
 
     // step 3 index the names for reverse lookup
     indexNames();
@@ -310,7 +304,7 @@ bool AirportDbGenerator::generate(QIODevice* out)
 #include "airportdb_p.h"
 #include "knowledgedb.h"
 #include "timezonedb.h"
-#include "timezonedb_data_p.h"
+#include "timezonedb_data.h"
 
 #include <limits>
 
@@ -331,33 +325,17 @@ static constexpr Airport airport_table[] = {
         out->write("\"}, ");
         CodeGen::writeCountryIsoCode(out, m_airportMap.value(it.value()).country);
         out->write(", ");
-        CodeGen::writeTimezone(out, m_airportMap.value(it.value()).tz);
+        CodeGen::writeCoordinate(out, m_airportMap.value(it.value()).coord);
         out->write("}, // ");
         out->write(m_airportMap.value(it.value()).label.toUtf8());
         out->write("\n");
     }
     out->write(R"(};
 
-// airport coordinates in latitude/longitude pairs
-// stored out of line of the airport_table to avoid alignment padding
-static constexpr Coordinate coordinate_table[] = {
-)");
-    // airport data tables - coordinates
-    // TODO: should be possible to squeeze into 48 bit per coordinate, as 10m resolution is good enough for us
-    for (auto it = m_iataMap.constBegin(); it != m_iataMap.constEnd(); ++it) {
-        const auto &airport = m_airportMap.value(it.value());
-        out->write("    ");
-        CodeGen::writeCoordinate(out, airport.coord);
-        out->write(", // ");
-        out->write(airport.iataCode.toUtf8());
-        out->write("\n");
-    }
-    out->write(R"(};
-
 // reverse name lookup string table for unique strings
 static const char name1_string_table[] =
 )");
-    // TODO prefix compression
+    // TODO suffix compression -> see KPublicTransport, that has generic code for this
     std::vector<Name1Index> string_offsets;
     string_offsets.reserve(m_labelMap.size());
     uint32_t label_offset = 0;
